# Changelog

## [0.1.0] - 2026-02-16

### Added
- Initial release
- `stix_to_graph()` function converting STIX bundles to NetworkX graphs
- Support for STIX 2.0 and 2.1
- MultiDiGraph and DiGraph output options
- SCO inclusion/exclusion toggle
- Sightings as nodes with typed edges
- Multiple bundle merging
- MITRE ATT&CK integration test
